<template>
    <v-snackbar v-model="show" :bottom="position === 'bottom'" :color="trueColor" :content-class="style" :left="left"
                :right="right" :transition="trueTransition"
                :timeout="trueTimeout" :top="position === 'top'">
        <v-icon v-if="icon" right small>{{ trueIcon }}</v-icon>
        {{ text }}
        <template v-slot:action="{ attrs }">
            <v-btn dark icon small text v-bind="attrs" @click="show=false">
                <v-icon small>mdi-close</v-icon>
            </v-btn>
        </template>
    </v-snackbar>
</template>

<script>
import {mapGetters, mapState} from 'vuex'

export default {
    name: "Snackbar",
    data() {
        return {
            show: false,
            type: "",
            text: "",
            timeout: -1,
            position: ""
        };
    },
    watch: {
        show(value) {
            if (!value) {
                this.$store.dispatch('SnackBar/setDefaultType')
            }
        }
    },
    computed: {
        ...mapState("SnackBar", ["right", "left", "style", "icon"]),
        ...mapGetters("SnackBar", ["getText", "getType", "getTimeOut"]),
        trueColor() {
            switch (this.type) {
                case 'success':
                case 'error':
                case 'info':
                case 'primary':
                case 'warning':
                    return this.type
                default:
                    return 'success'
            }
        },
        trueTimeout() {
            return this.timeout > 0 ? this.timeout : 3500; // sets timeout default value
        },
        trueIcon() {
            if (typeof this.icon === "boolean" && this.icon) {
                switch (this.type) {
                    case 'error':
                        return 'mdi-alert-outline'
                    case 'info':
                    case 'primary':
                        return 'mdi-information-slab-circle-outline'
                    case 'warning':
                        return 'mdi-alert-box'
                    default:
                        return 'mdi-check-circle-outline'
                }
            } else if (typeof this.icon === "string" && this.icon) {
                if (!this.icon.startsWith("mdi-")) {
                    return "mdi-".concat(this.icon)
                }
                return this.icon
            }
        },
        trueTransition() {
            if (this.position === 'bottom') {
                return 'slide-y-reverse-transition'
            } else if (this.position === 'top') {
                return 'fab-transition'
            }
            return 'v-snack-transition'
        },
    },
    created() {
        this.$store.subscribe((mutation, state) => {
            if (mutation.type === "SnackBar/showMessage") {
                this.text = state.SnackBar.text;
                this.type = state.SnackBar.type;
                this.timeout = state.SnackBar.timeout;
                this.position = state.SnackBar.position || 'top'
                this.show = true;
            }
        });
    }
};
</script>

<style scoped>
::v-deep .v-snack__wrapper {
    min-width: 0px;
}
</style>
